<?php
namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class Sm00006001VariacaoTabelaPrecoServicoFactory
{
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        
        $this->connection = $entityManager->getConnection();
    }
    
     /**
     * A função "validaTipoMedidaVariavel" verifica se o tipo de medida variável
     * ja está criado para a faixa existente.
     */
     
    public function validaTipoMedidaVariavel($params){
        
        $sql = "SELECT CDTPMEDIDAVARIAVEL, QTMEDIDAINIVARIACAO, QTMEDIDAFIMVARIACAO
                  FROM FCT_VARIACAOPRECBASESERV
                 WHERE NRSEQITPRECBSERV = :NRSEQITPRECBSERV 
                   AND CDTPMEDIDASERV = :CDTPMEDIDASERV
                   AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL
                   AND NRVARIACAOPRECBASESERV <> NVL(:NRVARIACAOPRECBASESERV, -1) 
                   AND NRORG = :NRORG";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
    /**
     * A função "insereVariacaoPreco" insere os valores de variação de preço 
     * ao inserir um novo tipo de medida na variação.
     */
    
    public function insereVariacaoPreco($params){
        
        $sql = "INSERT INTO FCT_VARIACAOPRECBASESERV(
                    NRVARIACAOPRECBASESERV, NRSEQITPRECBSERV, DTINIPBSERV, CDTPMEDIDASERV, CDTPMEDIDAVARIAVEL, 
                    QTMEDIDAINIVARIACAO, QTMEDIDAFIMVARIACAO, VRPRECOVARIACAO, DTFIMVALPBSERV, CDFILIAL, IDMULTIPVARIACAO, 
                    QTFRANQUIA, NRORG, DTINCLUSAO, NRORGINCLUSAO, CDOPERINCLUSAO, IDATIVO
                )
                VALUES (
                    :NRVARIACAOPRECBASESERV, :NRSEQITPRECBSERV, SYSDATE, :CDTPMEDIDASERV, :CDTPMEDIDAVARIAVEL,
                    :QTMEDIDAINIVARIACAO, :QTMEDIDAFIMVARIACAO, :VRPRECOVARIACAO, NULL, NULL, :IDMULTIPVARIACAO,
                    :QTFRANQUIA, :NRORG, SYSDATE, :NRORG, :OPERADOR, 'S'  
                )";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    /**
     * A função "editaVariacaoPreco" edita os valores de variação de preço
     * ao alterar um tipo de medida na variação.
     */
    
    public function editaVariacaoPreco($params){
        
        $sql = "UPDATE FCT_VARIACAOPRECBASESERV
                   SET IDMULTIPVARIACAO = :IDMULTIPVARIACAO,
                       QTFRANQUIA = :QTFRANQUIA,
                       DTULTATU = SYSDATE,
                       CDOPERULTATU = :OPERADOR,
                       NRORGULTATU = :NRORG
                 WHERE NRORG = :NRORG
                   AND NRSEQITPRECBSERV = :NRSEQITPRECBSERV
                   AND CDTPMEDIDASERV = :CDTPMEDIDASERV 
                   AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    
    /**
     * A função "deletaVariacaoPreco" insere os valores de variação de preço 
     * ao excluir um tipo de medida na variação.
     */
    
    public function deletaVariacaoPreco($params){
        
        $sql = "DELETE FROM FCT_VARIACAOPRECBASESERV
                 WHERE NRORG = :NRORG
                   AND NRSEQITPRECBSERV = :NRSEQITPRECBSERV
                   AND CDTPMEDIDASERV = :CDTPMEDIDASERV 
                   AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
    }
    
    
    /**
     * A função "sinconizaMedidaVariavel" busca as faixas de variação de uma 
     * medida variavel para sincronização
     */
    
    public function sinconizaMedidaVariavel($params){
        
        $sql = "SELECT CDTPMEDIDASERV, CDTPMEDIDAVARIAVEL, QTMEDIDAINIVARIACAO,
                      QTMEDIDAFIMVARIACAO, VRPERCVARIACAO
                 FROM FCT_VARIACAOTIPOMEDIDA
                WHERE CDTPMEDIDASERV = :CDTPMEDIDASERV 
                  AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL
                  AND NRORG = :NRORG
                ORDER BY QTMEDIDAINIVARIACAO";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
    
    /**
     *  A função "validaFranquiaFaixa" verifica se existem faixas de variação cuja 
     *  franquia esteja dentro dela ou que seja menor do que a franquia.
     */
     
    public function validaFranquiaFaixa($params){
        
        $sql = "SELECT COUNT(*) AS FAIXAS
                  FROM FCT_VARIACAOPRECBASESERV
                 WHERE NRORG = :NRORG
                   AND NRSEQITPRECBSERV = :NRSEQITPRECBSERV
                   AND CDTPMEDIDASERV = :CDTPMEDIDASERV 
                   AND CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL
                   AND ((:QTFRANQUIA BETWEEN QTMEDIDAINIVARIACAO AND QTMEDIDAFIMVARIACAO) 
                         OR (QTMEDIDAFIMVARIACAO < :QTFRANQUIA))";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
    
    /* Nesta função são buscadas as faixas de preço atuais da medida variável para 
       realziação da replicação da franquia  */
    
    public function buscaDadosReplicacao($params){
        
        $sql = "SELECT FCT_VARIACAOPRECBASESERV.NRVARIACAOPRECBASESERV, FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV, FCT_VARIACAOPRECBASESERV.CDTPMEDIDASERV, 
                       FCT_VARIACAOPRECBASESERV.CDTPMEDIDAVARIAVEL, FCT_VARIACAOPRECBASESERV.QTMEDIDAINIVARIACAO, FCT_VARIACAOPRECBASESERV.QTMEDIDAFIMVARIACAO, 
                       FCT_VARIACAOPRECBASESERV.VRPRECOVARIACAO,  FCT_VARIACAOPRECBASESERV.NRORG, FCT_VARIACAOPRECBASESERV.IDATIVO, FCT_VARIACAOPRECBASESERV.IDMULTIPVARIACAO, 
                       FCT_VARIACAOPRECBASESERV.QTFRANQUIA
                  FROM FCT_VARIACAOPRECBASESERV
                  JOIN FCT_ITPRECBASESERV 
                    ON FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV = FCT_ITPRECBASESERV.NRSEQITPRECBSERV
                   AND FCT_VARIACAOPRECBASESERV.NRORG = FCT_ITPRECBASESERV.NRORG
                 WHERE FCT_VARIACAOPRECBASESERV.CDTPMEDIDAVARIAVEL = :CDTPMEDIDAVARIAVEL 
                   AND FCT_ITPRECBASESERV.CDPRECBASESERV = (SELECT CDPRECBASESERV 
                                                             FROM FCT_ITPRECBASESERV 
                                                            WHERE NRSEQITPRECBSERV = :NRSEQITPRECBSERV
                                                              AND NRORG = :NRORG)
                   AND FCT_VARIACAOPRECBASESERV.NRSEQITPRECBSERV <> :NRSEQITPRECBSERV
                   AND FCT_VARIACAOPRECBASESERV.NRORG = :NRORG
                   ORDER BY NRSEQITPRECBSERV, QTMEDIDAINIVARIACAO, QTMEDIDAFIMVARIACAO";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
        
    }
    
}
?>