<?php

namespace Teknisa\Model\Teknisa\Repositories;

use Doctrine\ORM\EntityManager;

class OmParamOrg extends \Doctrine\ORM\EntityRepository {

    public function setEntityManager(EntityManager $entityManager) {
        $this->_em = $entityManager;
    }
    
    public function getOrganizationParameters($orgId, $orgDbUser = ""){
        $tableName = 'OM_PARAM_ORG';
        $joinTableOrganization = 'ORGANIZACAO';
        $joinTableClient = 'CLIENTE';
        if($orgDbUser) {
            $tableName = $orgDbUser . '.OM_PARAM_ORG';
            $joinTableOrganization = $orgDbUser . '.ORGANIZACAO';
            $joinTableClient = $orgDbUser . '.CLIENTE';
        }
        $query = <<<SQL
        SELECT TO_CHAR(CLI.DTVALARQPERS, 'DD/MM/YYYY') AS DTVALARQPERS, CLI.NRDIAVALPERS, TN.NRORG AS ORG_ID, TN.IDALLOWPRODUCTCALL, TN.IDUTIPRESTRICTION AS USE_RESTRICTION,
               TN.IDCOLETOR, TN.DSSTRINGCONEXAO, TN.IDUTWALLET, TN.DSUSUARIOBANCO, TN.DSSENHABANCO,
               TN.IDTPBANCO, CASE WHEN IDTPBANCO = 'ORACLE'
                               THEN 'Oracle'
                               WHEN IDTPBANCO = 'SQL_SERVER_2000'
                               THEN 'SQL Server 2000' 
                               WHEN IDTPBANCO = 'SQL_SERVER_2005'
                               THEN 'SQL Server 2005' 
                               WHEN IDTPBANCO = 'SQL_SERVER_2009'
                               THEN 'SQL Server 2009'
                               WHEN IDTPBANCO = 'MY_SQL'
                               THEN 'MySQL'
                               ELSE NULL
                           END AS NMTPBANCO
          FROM $tableName TN
          JOIN $joinTableOrganization ORG ON ORG.NRORG = TN.NRORG
          LEFT JOIN $joinTableClient CLI ON ORG.NRPARCNEGOCIO = CLI.NRPARCNEGOCIO
         WHERE TN.NRORG = :orgId
SQL;
        $params = array(
            "orgId" => $orgId
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }
    
    
    public function getOrganizationFinancialDefaultInfo($orgId){
       
        $query = <<<SQL
        SELECT TO_CHAR(CLI.DTVALARQPERS, 'DD/MM/YYYY') AS DTVALARQPERS, CLI.NRDIAVALPERS
          FROM ORGANIZACAO ORG
          JOIN CLIENTE CLI ON ORG.NRPARCNEGOCIO = CLI.NRPARCNEGOCIO
          WHERE ORG.NRORG = :orgId
SQL;
        $params = array(
            "orgId" => $orgId
        );
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }
    
    public function getOrganizationRestrictionByIp($orgId, $conditions = "", $orgDbUser = ""){
        $tableName = 'OM_IP_RESTRICTION';
        if($orgDbUser) {
            $tableName = $orgDbUser . '.OM_IP_RESTRICTION';
        }
        $query = <<<SQL
        SELECT *
          FROM (SELECT NR_IP_RESTRICTION AS ID, IDATIVO AS ACTIVE,
                       DS_IPV4_RESTRICTED AS IPV4, DS_IPV6_RESTRICTED AS IPV6,
                       DS_OBS_IP_RESTRICTED AS DESCRIPTION
                  FROM $tableName
                 WHERE NRORG = :orgId)
         WHERE 1=1
               $conditions
SQL;
        $params = array(
            "orgId" => $orgId
        );
        
        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

    public function getOrganizationDbUser($orgDbUser){
        $query = <<<SQL
        SELECT USER_ID, USERNAME
          FROM ALL_USERS
         WHERE USERNAME = :USERNAME
SQL;
        $params = array(
            "USERNAME" => $orgDbUser
        );

        return $this->getEntityManager()->getConnection()->fetchAll($query, $params);
    }

}